@@ -1,5 +1,5 @@
 package HTML::Spelling::Site::Checker;
-$HTML::Spelling::Site::Checker::VERSION = '0.4.0';
+$HTML::Spelling::Site::Checker::VERSION = '0.4.1';
 use strict;
 use warnings;
 use autodie;
@@ -160,7 +160,7 @@ s{\A(?:(?:ֹו?(?:ש|ל|מ|ב|כש|לכש|מה|שה|לכשה|ב-))|ו)-?}{};
             }
         };
 
-        open( my $fh, "<:utf8", $filename );
+        open( my $fh, "<:encoding(UTF-8)", $filename );
 
         HTML::Parser->new(
             api_version => 3,
@@ -240,13 +240,9 @@ __END__
 
 =encoding UTF-8
 
-=head1 NAME
-
-HTML::Spelling::Site::Checker
-
 =head1 VERSION
 
-version 0.4.0
+version 0.4.1
 
 =head1 SYNOPSIS
 
@@ -410,10 +406,6 @@ local HTML files.
 
 HTML::Spelling::Site::Checker - does the actual checking.
 
-=head1 VERSION
-
-version 0.4.0
-
 =head1 METHODS
 
 =head2 my $obj = HTML::Spelling::Site::Checker->new({ whitelist_parser => $parser_obj, check_word_cb => sub { ... }, timestamp_cache_fn => '/path/to/timestamp-cache.json' })
